@@ -12,7 +12,8 @@ for await (const conn of listener) {
   (async () => {
     const requests = Deno.serveHttp(conn);
     for await (const { respondWith } of requests) {
-      respondWith(new Response(body));
+      respondWith(new Response(body))
+        .catch((e) => console.log(e));
     }
   })();
 }
