@@ -71,12 +71,12 @@ fn standalone_args() {
     dir.path().join("args")
   };
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/028_args.ts")
+    .arg("./028_args.ts")
     .arg("a")
     .arg("b")
     .stdout(std::process::Stdio::piped())
@@ -107,12 +107,12 @@ fn standalone_error() {
     dir.path().join("error")
   };
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/standalone_error.ts")
+    .arg("./standalone_error.ts")
     .stdout(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -143,12 +143,12 @@ fn standalone_no_module_load() {
     dir.path().join("hello")
   };
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/standalone_import.ts")
+    .arg("./standalone_import.ts")
     .stdout(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -178,12 +178,12 @@ fn standalone_load_datauri() {
     dir.path().join("load_datauri")
   };
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/standalone_import_datauri.ts")
+    .arg("./standalone_import_datauri.ts")
     .stdout(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -210,12 +210,12 @@ fn standalone_compiler_ops() {
     dir.path().join("standalone_compiler_ops")
   };
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/standalone_compiler_ops.ts")
+    .arg("./standalone_compiler_ops.ts")
     .stdout(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -243,12 +243,12 @@ fn compile_with_directory_exists_error() {
   };
   std::fs::create_dir(&exe).expect("cannot create directory");
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/028_args.ts")
+    .arg("./028_args.ts")
     .stderr(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -272,12 +272,12 @@ fn compile_with_conflict_file_exists_error() {
   std::fs::write(&exe, b"SHOULD NOT BE OVERWRITTEN")
     .expect("cannot create file");
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/028_args.ts")
+    .arg("./028_args.ts")
     .stderr(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -303,12 +303,12 @@ fn compile_and_overwrite_file() {
     dir.path().join("args")
   };
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/028_args.ts")
+    .arg("./028_args.ts")
     .stderr(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -318,12 +318,12 @@ fn compile_and_overwrite_file() {
   assert!(&exe.exists());
 
   let recompile_output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/028_args.ts")
+    .arg("./028_args.ts")
     .stderr(std::process::Stdio::piped())
     .spawn()
     .unwrap()
@@ -341,7 +341,7 @@ fn standalone_runtime_flags() {
     dir.path().join("flags")
   };
   let output = util::deno_cmd()
-    .current_dir(util::root_path())
+    .current_dir(util::testdata_path())
     .arg("compile")
     .arg("--unstable")
     .arg("--allow-read")
@@ -349,7 +349,7 @@ fn standalone_runtime_flags() {
     .arg("1")
     .arg("--output")
     .arg(&exe)
-    .arg("./cli/tests/standalone_runtime_flags.ts")
+    .arg("./standalone_runtime_flags.ts")
     .stdout(std::process::Stdio::piped())
     .spawn()
     .unwrap()
