@@ -335,7 +335,6 @@ itest!(_089_run_allow_list {
   output: "089_run_allow_list.ts.out",
 });
 
-#[cfg(unix)]
 #[test]
 fn _090_run_permissions_request() {
   let args = "run --quiet 090_run_permissions_request.ts";
@@ -622,6 +621,12 @@ itest!(error_026_remote_import_error {
   http_server: true,
 });
 
+itest!(error_for_await {
+  args: "run --reload error_for_await.ts",
+  output: "error_for_await.ts.out",
+  exit_code: 1,
+});
+
 itest!(error_missing_module_named_import {
   args: "run --reload error_missing_module_named_import.ts",
   output: "error_missing_module_named_import.ts.out",
@@ -1720,7 +1725,6 @@ mod permissions {
     assert!(!err.contains(util::PERMISSION_DENIED_PATTERN));
   }
 
-  #[cfg(unix)]
   #[test]
   fn _061_permissions_request() {
     let args = "run --quiet 061_permissions_request.ts";
@@ -1736,7 +1740,6 @@ mod permissions {
     ]);
   }
 
-  #[cfg(unix)]
   #[test]
   fn _062_permissions_request_global() {
     let args = "run --quiet 062_permissions_request_global.ts";
@@ -1760,7 +1763,6 @@ mod permissions {
     output: "064_permissions_revoke_global.ts.out",
   });
 
-  #[cfg(unix)]
   #[test]
   fn _066_prompt() {
     let args = "run --quiet --unstable 066_prompt.ts";
@@ -1855,7 +1857,6 @@ itest!(byte_order_mark {
   output: "byte_order_mark.out",
 });
 
-#[cfg(unix)]
 #[test]
 fn issue9750() {
   use util::PtyData::*;
@@ -1879,3 +1880,9 @@ itest!(dom_exception_formatting {
   output: "dom_exception_formatting.ts.out",
   exit_code: 1,
 });
+
+itest!(long_data_url_formatting {
+  args: "run long_data_url_formatting.ts",
+  output: "long_data_url_formatting.ts.out",
+  exit_code: 1,
+});
