@@ -10,87 +10,87 @@ import {
 
 unitTest(
   { ignore: Deno.build.os !== "windows" },
-  function signalsNotImplemented(): void {
+  function signalsNotImplemented() {
     assertThrows(
       () => {
-        Deno.signal(1);
+        Deno.signal("SIGINT");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.alarm(); // for SIGALRM
+        Deno.signal("SIGALRM");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.child(); // for SIGCHLD
+        Deno.signal("SIGCHLD");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.hungup(); // for SIGHUP
+        Deno.signal("SIGHUP");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.interrupt(); // for SIGINT
+        Deno.signal("SIGINT");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.io(); // for SIGIO
+        Deno.signal("SIGIO");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.pipe(); // for SIGPIPE
+        Deno.signal("SIGPIPE");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.quit(); // for SIGQUIT
+        Deno.signal("SIGQUIT");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.terminate(); // for SIGTERM
+        Deno.signal("SIGTERM");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.userDefined1(); // for SIGUSR1
+        Deno.signal("SIGUSR1");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.userDefined2(); // for SIGURS2
+        Deno.signal("SIGUSR2");
       },
       Error,
       "not implemented",
     );
     assertThrows(
       () => {
-        Deno.signals.windowChange(); // for SIGWINCH
+        Deno.signal("SIGWINCH");
       },
       Error,
       "not implemented",
@@ -100,18 +100,18 @@ unitTest(
 
 unitTest(
   { ignore: Deno.build.os === "windows", perms: { run: true, net: true } },
-  async function signalStreamTest(): Promise<void> {
+  async function signalStreamTest() {
     const resolvable = deferred();
     // This prevents the program from exiting.
     const t = setInterval(() => {}, 1000);
 
     let c = 0;
-    const sig = Deno.signal(Deno.Signal.SIGUSR1);
+    const sig = Deno.signal("SIGUSR1");
     setTimeout(async () => {
       await delay(20);
       for (const _ of Array(3)) {
         // Sends SIGUSR1 3 times.
-        Deno.kill(Deno.pid, Deno.Signal.SIGUSR1);
+        Deno.kill(Deno.pid, "SIGUSR1");
         await delay(20);
       }
       sig.dispose();
@@ -132,13 +132,13 @@ unitTest(
 // This tests that pending op_signal_poll doesn't block the runtime from exiting the process.
 unitTest(
   { ignore: Deno.build.os === "windows", perms: { run: true, read: true } },
-  async function signalStreamExitTest(): Promise<void> {
+  async function signalStreamExitTest() {
     const p = Deno.run({
       cmd: [
         Deno.execPath(),
         "eval",
         "--unstable",
-        "(async () => { for await (const _ of Deno.signals.io()) {} })()",
+        "(async () => { for await (const _ of Deno.signal('SIGIO')) {} })()",
       ],
     });
     const res = await p.status();
@@ -149,14 +149,14 @@ unitTest(
 
 unitTest(
   { ignore: Deno.build.os === "windows", perms: { run: true } },
-  async function signalPromiseTest(): Promise<void> {
+  async function signalPromiseTest() {
     const resolvable = deferred();
     // This prevents the program from exiting.
     const t = setInterval(() => {}, 1000);
 
-    const sig = Deno.signal(Deno.Signal.SIGUSR1);
+    const sig = Deno.signal("SIGUSR1");
     setTimeout(() => {
-      Deno.kill(Deno.pid, Deno.Signal.SIGUSR1);
+      Deno.kill(Deno.pid, "SIGUSR1");
       resolvable.resolve();
     }, 20);
     await sig;
@@ -170,13 +170,13 @@ unitTest(
 // https://github.com/denoland/deno/issues/9806
 unitTest(
   { ignore: Deno.build.os === "windows", perms: { run: true } },
-  async function signalPromiseTest2(): Promise<void> {
+  async function signalPromiseTest2() {
     const resolvable = deferred();
     // This prevents the program from exiting.
     const t = setInterval(() => {}, 1000);
 
     let called = false;
-    const sig = Deno.signal(Deno.Signal.SIGUSR1);
+    const sig = Deno.signal("SIGUSR1");
     sig.then(() => {
       called = true;
     });
@@ -198,39 +198,39 @@ unitTest(
 
 unitTest(
   { ignore: Deno.build.os === "windows", perms: { run: true } },
-  function signalShorthandsTest(): void {
+  function signalShorthandsTest() {
     let s: Deno.SignalStream;
-    s = Deno.signals.alarm(); // for SIGALRM
+    s = Deno.signal("SIGALRM");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.child(); // for SIGCHLD
+    s = Deno.signal("SIGCHLD");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.hungup(); // for SIGHUP
+    s = Deno.signal("SIGHUP");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.interrupt(); // for SIGINT
+    s = Deno.signal("SIGINT");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.io(); // for SIGIO
+    s = Deno.signal("SIGIO");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.pipe(); // for SIGPIPE
+    s = Deno.signal("SIGPIPE");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.quit(); // for SIGQUIT
+    s = Deno.signal("SIGQUIT");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.terminate(); // for SIGTERM
+    s = Deno.signal("SIGTERM");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.userDefined1(); // for SIGUSR1
+    s = Deno.signal("SIGUSR1");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.userDefined2(); // for SIGURS2
+    s = Deno.signal("SIGUSR2");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
-    s = Deno.signals.windowChange(); // for SIGWINCH
+    s = Deno.signal("SIGWINCH");
     assert(s instanceof Deno.SignalStream);
     s.dispose();
   },
