@@ -11,12 +11,13 @@ import {
   unitTest,
 } from "./test_util.ts";
 import { BufReader, BufWriter } from "../../../test_util/std/io/bufio.ts";
+import { readAll } from "../../../test_util/std/io/util.ts";
 import { TextProtoReader } from "../../../test_util/std/textproto/mod.ts";
 
 const encoder = new TextEncoder();
 const decoder = new TextDecoder();
 
-async function sleep(msec: number): Promise<void> {
+async function sleep(msec: number) {
   await new Promise((res, _rej) => setTimeout(res, msec));
 }
 
@@ -24,20 +25,20 @@ function unreachable(): never {
   throw new Error("Unreachable code reached");
 }
 
-unitTest(async function connectTLSNoPerm(): Promise<void> {
+unitTest(async function connectTLSNoPerm() {
   await assertThrowsAsync(async () => {
-    await Deno.connectTls({ hostname: "github.com", port: 443 });
+    await Deno.connectTls({ hostname: "deno.land", port: 443 });
   }, Deno.errors.PermissionDenied);
 });
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function connectTLSInvalidHost(): Promise<void> {
+  async function connectTLSInvalidHost() {
     const listener = await Deno.listenTls({
       hostname: "localhost",
       port: 3567,
-      certFile: "cli/tests/tls/localhost.crt",
-      keyFile: "cli/tests/tls/localhost.key",
+      certFile: "cli/tests/testdata/tls/localhost.crt",
+      keyFile: "cli/tests/testdata/tls/localhost.key",
     });
 
     await assertThrowsAsync(async () => {
@@ -48,24 +49,24 @@ unitTest(
   },
 );
 
-unitTest(async function connectTLSCertFileNoReadPerm(): Promise<void> {
+unitTest(async function connectTLSCertFileNoReadPerm() {
   await assertThrowsAsync(async () => {
     await Deno.connectTls({
-      hostname: "github.com",
+      hostname: "deno.land",
       port: 443,
-      certFile: "cli/tests/tls/RootCA.crt",
+      certFile: "cli/tests/testdata/tls/RootCA.crt",
     });
   }, Deno.errors.PermissionDenied);
 });
 
 unitTest(
   { perms: { read: true, net: true } },
-  function listenTLSNonExistentCertKeyFiles(): void {
+  function listenTLSNonExistentCertKeyFiles() {
     const options = {
       hostname: "localhost",
       port: 3500,
-      certFile: "cli/tests/tls/localhost.crt",
-      keyFile: "cli/tests/tls/localhost.key",
+      certFile: "cli/tests/testdata/tls/localhost.crt",
+      keyFile: "cli/tests/testdata/tls/localhost.key",
     };
 
     assertThrows(() => {
@@ -84,13 +85,13 @@ unitTest(
   },
 );
 
-unitTest({ perms: { net: true } }, function listenTLSNoReadPerm(): void {
+unitTest({ perms: { net: true } }, function listenTLSNoReadPerm() {
   assertThrows(() => {
     Deno.listenTls({
       hostname: "localhost",
       port: 3500,
-      certFile: "cli/tests/tls/localhost.crt",
-      keyFile: "cli/tests/tls/localhost.key",
+      certFile: "cli/tests/testdata/tls/localhost.crt",
+      keyFile: "cli/tests/testdata/tls/localhost.key",
     });
   }, Deno.errors.PermissionDenied);
 });
@@ -99,12 +100,12 @@ unitTest(
   {
     perms: { read: true, write: true, net: true },
   },
-  function listenTLSEmptyKeyFile(): void {
+  function listenTLSEmptyKeyFile() {
     const options = {
       hostname: "localhost",
       port: 3500,
-      certFile: "cli/tests/tls/localhost.crt",
-      keyFile: "cli/tests/tls/localhost.key",
+      certFile: "cli/tests/testdata/tls/localhost.crt",
+      keyFile: "cli/tests/testdata/tls/localhost.key",
     };
 
     const testDir = Deno.makeTempDirSync();
@@ -124,12 +125,12 @@ unitTest(
 
 unitTest(
   { perms: { read: true, write: true, net: true } },
-  function listenTLSEmptyCertFile(): void {
+  function listenTLSEmptyCertFile() {
     const options = {
       hostname: "localhost",
       port: 3500,
-      certFile: "cli/tests/tls/localhost.crt",
-      keyFile: "cli/tests/tls/localhost.key",
+      certFile: "cli/tests/testdata/tls/localhost.crt",
+      keyFile: "cli/tests/testdata/tls/localhost.key",
     };
 
     const testDir = Deno.makeTempDirSync();
@@ -149,7 +150,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function dialAndListenTLS(): Promise<void> {
+  async function dialAndListenTLS() {
     const resolvable = deferred();
     const hostname = "localhost";
     const port = 3500;
@@ -157,8 +158,8 @@ unitTest(
     const listener = Deno.listenTls({
       hostname,
       port,
-      certFile: "cli/tests/tls/localhost.crt",
-      keyFile: "cli/tests/tls/localhost.key",
+      certFile: "cli/tests/testdata/tls/localhost.crt",
+      keyFile: "cli/tests/testdata/tls/localhost.key",
     });
 
     const response = encoder.encode(
@@ -166,7 +167,7 @@ unitTest(
     );
 
     listener.accept().then(
-      async (conn): Promise<void> => {
+      async (conn) => {
         assert(conn.remoteAddr != null);
         assert(conn.localAddr != null);
         await conn.write(response);
@@ -181,7 +182,7 @@ unitTest(
     const conn = await Deno.connectTls({
       hostname,
       port,
-      certFile: "cli/tests/tls/RootCA.pem",
+      certFile: "cli/tests/testdata/tls/RootCA.pem",
     });
     assert(conn.rid > 0);
     const w = new BufWriter(conn);
@@ -221,15 +222,15 @@ async function tlsPair(): Promise<[Deno.Conn, Deno.Conn]> {
   const listener = Deno.listenTls({
     hostname: "localhost",
     port,
-    certFile: "cli/tests/tls/localhost.crt",
-    keyFile: "cli/tests/tls/localhost.key",
+    certFile: "cli/tests/testdata/tls/localhost.crt",
+    keyFile: "cli/tests/testdata/tls/localhost.key",
   });
 
   const acceptPromise = listener.accept();
   const connectPromise = Deno.connectTls({
     hostname: "localhost",
     port,
-    certFile: "cli/tests/tls/RootCA.pem",
+    certFile: "cli/tests/testdata/tls/RootCA.pem",
   });
   const endpoints = await Promise.all([acceptPromise, connectPromise]);
 
@@ -242,7 +243,7 @@ async function sendThenCloseWriteThenReceive(
   conn: Deno.Conn,
   chunkCount: number,
   chunkSize: number,
-): Promise<void> {
+) {
   const byteCount = chunkCount * chunkSize;
   const buf = new Uint8Array(chunkSize); // Note: buf is size of _chunk_.
   let n: number;
@@ -274,7 +275,7 @@ async function receiveThenSend(
   conn: Deno.Conn,
   chunkCount: number,
   chunkSize: number,
-): Promise<void> {
+) {
   const byteCount = chunkCount * chunkSize;
   const buf = new Uint8Array(byteCount); // Note: buf size equals `byteCount`.
   let n: number;
@@ -301,7 +302,7 @@ async function receiveThenSend(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsServerStreamHalfCloseSendOneByte(): Promise<void> {
+  async function tlsServerStreamHalfCloseSendOneByte() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(serverConn, 1, 1),
@@ -312,7 +313,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsClientStreamHalfCloseSendOneByte(): Promise<void> {
+  async function tlsClientStreamHalfCloseSendOneByte() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(clientConn, 1, 1),
@@ -323,7 +324,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsServerStreamHalfCloseSendOneChunk(): Promise<void> {
+  async function tlsServerStreamHalfCloseSendOneChunk() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(serverConn, 1, 1 << 20 /* 1 MB */),
@@ -334,7 +335,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsClientStreamHalfCloseSendOneChunk(): Promise<void> {
+  async function tlsClientStreamHalfCloseSendOneChunk() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(clientConn, 1, 1 << 20 /* 1 MB */),
@@ -345,7 +346,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsServerStreamHalfCloseSendManyBytes(): Promise<void> {
+  async function tlsServerStreamHalfCloseSendManyBytes() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(serverConn, 100, 1),
@@ -356,7 +357,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsClientStreamHalfCloseSendManyBytes(): Promise<void> {
+  async function tlsClientStreamHalfCloseSendManyBytes() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(clientConn, 100, 1),
@@ -367,7 +368,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsServerStreamHalfCloseSendManyChunks(): Promise<void> {
+  async function tlsServerStreamHalfCloseSendManyChunks() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(serverConn, 100, 1 << 16 /* 64 kB */),
@@ -378,7 +379,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsClientStreamHalfCloseSendManyChunks(): Promise<void> {
+  async function tlsClientStreamHalfCloseSendManyChunks() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendThenCloseWriteThenReceive(clientConn, 100, 1 << 16 /* 64 kB */),
@@ -387,7 +388,7 @@ unitTest(
   },
 );
 
-async function sendAlotReceiveNothing(conn: Deno.Conn): Promise<void> {
+async function sendAlotReceiveNothing(conn: Deno.Conn) {
   // Start receive op.
   const readBuf = new Uint8Array(1024);
   const readPromise = conn.read(readBuf);
@@ -410,7 +411,7 @@ async function sendAlotReceiveNothing(conn: Deno.Conn): Promise<void> {
   );
 }
 
-async function receiveAlotSendNothing(conn: Deno.Conn): Promise<void> {
+async function receiveAlotSendNothing(conn: Deno.Conn) {
   const readBuf = new Uint8Array(1024);
   let n: number | null;
 
@@ -428,7 +429,7 @@ async function receiveAlotSendNothing(conn: Deno.Conn): Promise<void> {
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsServerStreamCancelRead(): Promise<void> {
+  async function tlsServerStreamCancelRead() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendAlotReceiveNothing(serverConn),
@@ -439,7 +440,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsClientStreamCancelRead(): Promise<void> {
+  async function tlsClientStreamCancelRead() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendAlotReceiveNothing(clientConn),
@@ -448,7 +449,7 @@ unitTest(
   },
 );
 
-async function sendReceiveEmptyBuf(conn: Deno.Conn): Promise<void> {
+async function sendReceiveEmptyBuf(conn: Deno.Conn) {
   const byteBuf = new Uint8Array([1]);
   const emptyBuf = new Uint8Array(0);
   let n: number | null;
@@ -485,7 +486,7 @@ async function sendReceiveEmptyBuf(conn: Deno.Conn): Promise<void> {
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsStreamSendReceiveEmptyBuf(): Promise<void> {
+  async function tlsStreamSendReceiveEmptyBuf() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       sendReceiveEmptyBuf(serverConn),
@@ -494,12 +495,12 @@ unitTest(
   },
 );
 
-function immediateClose(conn: Deno.Conn): Promise<void> {
+function immediateClose(conn: Deno.Conn) {
   conn.close();
   return Promise.resolve();
 }
 
-async function closeWriteAndClose(conn: Deno.Conn): Promise<void> {
+async function closeWriteAndClose(conn: Deno.Conn) {
   await conn.closeWrite();
 
   if (await conn.read(new Uint8Array(1)) !== null) {
@@ -511,7 +512,7 @@ async function closeWriteAndClose(conn: Deno.Conn): Promise<void> {
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsServerStreamImmediateClose(): Promise<void> {
+  async function tlsServerStreamImmediateClose() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       immediateClose(serverConn),
@@ -522,7 +523,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsClientStreamImmediateClose(): Promise<void> {
+  async function tlsClientStreamImmediateClose() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       closeWriteAndClose(serverConn),
@@ -533,7 +534,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function tlsClientAndServerStreamImmediateClose(): Promise<void> {
+  async function tlsClientAndServerStreamImmediateClose() {
     const [serverConn, clientConn] = await tlsPair();
     await Promise.all([
       immediateClose(serverConn),
@@ -547,13 +548,13 @@ async function tlsWithTcpFailureTestImpl(
   cipherByteCount: number,
   failureMode: "corruption" | "shutdown",
   reverse: boolean,
-): Promise<void> {
+) {
   const tlsPort = getPort();
   const tlsListener = Deno.listenTls({
     hostname: "localhost",
     port: tlsPort,
-    certFile: "cli/tests/tls/localhost.crt",
-    keyFile: "cli/tests/tls/localhost.key",
+    certFile: "cli/tests/testdata/tls/localhost.crt",
+    keyFile: "cli/tests/testdata/tls/localhost.key",
   });
 
   const tcpPort = getPort();
@@ -569,7 +570,7 @@ async function tlsWithTcpFailureTestImpl(
     Deno.connectTls({
       hostname: "localhost",
       port: tcpPort,
-      certFile: "cli/tests/tls/RootCA.crt",
+      certFile: "cli/tests/testdata/tls/RootCA.crt",
     }),
   ]);
 
@@ -723,7 +724,7 @@ async function tlsWithTcpFailureTestImpl(
     conn: Deno.Conn,
     byte: number,
     count: number,
-  ): Promise<void> {
+  ) {
     let buf = new Uint8Array(1 << 12 /* 4 kB */);
     buf.fill(byte);
 
@@ -739,7 +740,7 @@ async function tlsWithTcpFailureTestImpl(
     conn: Deno.Conn,
     byte: number,
     count: number,
-  ): Promise<void> {
+  ) {
     let buf = new Uint8Array(1 << 12 /* 4 kB */);
     while (count > 0) {
       buf = buf.subarray(0, Math.min(buf.length, count));
@@ -761,7 +762,7 @@ async function tlsWithTcpFailureTestImpl(
     sink: Deno.Conn,
     count: number,
     interruptPromise: Deferred<void>,
-  ): Promise<void> {
+  ) {
     let buf = new Uint8Array(1 << 12 /* 4 kB */);
     while (count > 0) {
       buf = buf.subarray(0, Math.min(buf.length, count));
@@ -844,8 +845,8 @@ function createHttpsListener(port: number): Deno.Listener {
   const listener = Deno.listenTls({
     hostname: "localhost",
     port,
-    certFile: "./cli/tests/tls/localhost.crt",
-    keyFile: "./cli/tests/tls/localhost.key",
+    certFile: "./cli/tests/testdata/tls/localhost.crt",
+    keyFile: "./cli/tests/testdata/tls/localhost.key",
   });
 
   serve(listener);
@@ -913,7 +914,7 @@ async function curl(url: string): Promise<string> {
 
 unitTest(
   { perms: { read: true, net: true, run: true } },
-  async function curlFakeHttpsServer(): Promise<void> {
+  async function curlFakeHttpsServer() {
     const port = getPort();
     const listener = createHttpsListener(port);
 
@@ -937,7 +938,7 @@ unitTest(
 
 unitTest(
   { perms: { read: true, net: true } },
-  async function startTls(): Promise<void> {
+  async function startTls() {
     const hostname = "smtp.gmail.com";
     const port = 587;
     const encoder = new TextEncoder();
@@ -985,3 +986,76 @@ unitTest(
     conn.close();
   },
 );
+
+unitTest(
+  { perms: { read: true, net: true } },
+  async function connectTLSBadClientCertPrivateKey(): Promise<void> {
+    await assertThrowsAsync(async () => {
+      await Deno.connectTls({
+        hostname: "deno.land",
+        port: 443,
+        certChain: "bad data",
+        privateKey: await Deno.readTextFile(
+          "cli/tests/testdata/tls/localhost.key",
+        ),
+      });
+    }, Deno.errors.InvalidData);
+  },
+);
+
+unitTest(
+  { perms: { read: true, net: true } },
+  async function connectTLSBadPrivateKey(): Promise<void> {
+    await assertThrowsAsync(async () => {
+      await Deno.connectTls({
+        hostname: "deno.land",
+        port: 443,
+        certChain: await Deno.readTextFile(
+          "cli/tests/testdata/tls/localhost.crt",
+        ),
+        privateKey: "bad data",
+      });
+    }, Deno.errors.InvalidData);
+  },
+);
+
+unitTest(
+  { perms: { read: true, net: true } },
+  async function connectTLSNotPrivateKey(): Promise<void> {
+    await assertThrowsAsync(async () => {
+      await Deno.connectTls({
+        hostname: "deno.land",
+        port: 443,
+        certChain: await Deno.readTextFile(
+          "cli/tests/testdata/tls/localhost.crt",
+        ),
+        privateKey: "",
+      });
+    }, Deno.errors.InvalidData);
+  },
+);
+
+unitTest(
+  { perms: { read: true, net: true } },
+  async function connectWithClientCert() {
+    // The test_server running on port 4552 responds with 'PASS' if client
+    // authentication was successful. Try it by running test_server and
+    //   curl --key cli/tests/testdata/tls/localhost.key \
+    //        --cert cli/tests/testdata/tls/localhost.crt \
+    //        --cacert cli/tests/testdata/tls/RootCA.crt https://localhost:4552/
+    const conn = await Deno.connectTls({
+      hostname: "localhost",
+      port: 4552,
+      certChain: await Deno.readTextFile(
+        "cli/tests/testdata/tls/localhost.crt",
+      ),
+      privateKey: await Deno.readTextFile(
+        "cli/tests/testdata/tls/localhost.key",
+      ),
+      certFile: "cli/tests/testdata/tls/RootCA.crt",
+    });
+    const result = decoder.decode(await readAll(conn));
+    assertEquals(result, "PASS");
+    conn.close();
+  },
+);
